@@ -4,7 +4,7 @@ from serviceregistry import ServiceRegistry
 from pythonioc import serviceproxy
 import inspect
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 #
 # global instance, if the Service-Decorator is used for classes and instances.
@@ -58,8 +58,8 @@ def Inject(service):
 def registerService(serviceClass, serviceName=None):
     __getGlobalServiceRegistry().registerService(serviceClass, serviceName)
     
-def registerServiceInstance(instance, serviceName=None):
-    __getGlobalServiceRegistry().registerServiceInstance(instance, serviceName)
+def registerServiceInstance(instance, serviceName=None, overwrite=False):
+    __getGlobalServiceRegistry().registerServiceInstance(instance, serviceName, overwrite)
 
 def getService(service):
     """
